@@ -277,7 +277,7 @@ class BottleClient:
         result = []
         for node, updates in gene_data.items():  ## only primitive nodes at this time.
             for gene, value in updates.items():
-                response = requests.post(f'{self.url}{self.genome.primitive_map[node]}/genome', verify=self.secure, headers=self.headers, json={'data': {gene: value}}).json()
+                response = requests.post(f'{self.url}{self.genome.primitive_map[node]}/genome/update', verify=self.secure, headers=self.headers, json={'data': {gene: value}}).json()
                 if 'error' in response or response["message"] != 'updated-genes':
                     self.system_failures.append({node: response})
                     print("System Failure:", {node: response})
@@ -293,15 +293,12 @@ class BottleClient:
             raise ConnectionError('Not connected to a bottle. You must call `connect()` on a BottleClient instance before making queries')
         if isinstance(genome, io.TextIOBase):
             genome = json.load(genome)
-
-        self.genome.change_genes(genome)
-        response = requests.post(f'{self.url}genome', verify=self.secure, headers=self.headers, json={'genome': genome})
-
-        if response.status_code != 200:
-            self.system_failures.append({'bottle-api': response.json()})
-            print("System Failure:", {'bottle-api': response.json()})
-
-        return response.json()
+        response = requests.post(f'{self.url}genome/inject', verify=self.secure, headers=self.headers, json={'genome': genome}).json()
+        if 'error' not in response:
+            self.genome = Genome(genome)
+            self.genie = self.genome.agent
+            self.all_nodes = [{"name": i['name'], "id": i['id']} for i in self.genome.primitives.values()]
+        return response
 
     def get_cost_benefit(self, nodes: List = None) -> List:
         """Return cost benefit"""
@@ -466,19 +463,29 @@ class BottleClient:
 
     def ping(self, nodes: List = None) -> List[Dict[str, Any]]:
         """Ping a node to ensure it's up."""
-        if nodes is None:
-            nodes = self.all_nodes
-
         if not self._connected:
             raise ConnectionError(
                 'Not connected to a bottle. You must call `connect()` on a BottleClient instance before making queries')
+        if nodes is None:
+            return requests.get(f'{self.url}bottle/ping', headers=self.headers).json()
+        if nodes:
+            results = []
+            for node in nodes:
+                response = requests.get(f'{self.url}{self.genome.primitive_map[node]}/ping', verify=self.secure,
+                                        headers=self.headers).json()
+                if 'error' in response or response["message"] != 'okay':
+                    self.system_failures.append({node: response})
+                    print("System Failure:", {node["name"]: response})
+                    if len(nodes) == 1 and self.summarize_for_single_node:
+                        return response['message']
+                results.append({node: response["message"]})
+            return results
 
-        return requests.get(f'{self.url}ping', headers=self.headers).json()
 
-    def define_mood(self, mood_data: Dict) -> List:
+    def define_mood(self, mood_list: List, nodes: List = None) -> List:
         """
         *mood_data* should be of the format:
-            {node-name: {emotion: weight}}
+            [emotive-1, emotive-2]
 
         where node-name is the *name* of a primitive or manipulative.
         """
@@ -486,22 +493,23 @@ class BottleClient:
             raise ConnectionError(
                 'Not connected to a bottle. You must call `connect()` on a BottleClient instance before making queries')
         results = []
-        for node, mood_list in mood_data.items():  ## only primitive nodes at this time.
+        if nodes is None:
+            nodes = [node["name"] for node in self.all_nodes]
+        for node in nodes:
             response = requests.post(f'{self.url}{self.genome.primitive_map[node]}/mood/define', verify=self.secure,
                                      headers=self.headers, json={'data': mood_list}).json()
-            if 'error' in response or response["message"] != 'updated-genes':
+            if 'error' in response or response["message"] != 'defined-mood':
                 self.system_failures.append({node: response})
                 print("System Failure:", {node: response})
-                if len(mood_data) == 1 and self.summarize_for_single_node:
+                if len(nodes) == 1 and self.summarize_for_single_node:
                     return response['message']
             results.append({node: response["message"]})
         return results
 
-
-    def set_mood(self, mood_data: Dict) -> List:
+    def set_mood(self, mood_data: Dict, nodes: List = None) -> List:
         """
         *mood_data* should be of the format:
-            {node-name: {mood: value}}
+            {node-name: {emotive-1: value, emotive-2: value}}
 
         where node-name is the *name* of a primitive or manipulative.
         """
@@ -509,13 +517,16 @@ class BottleClient:
             raise ConnectionError(
                 'Not connected to a bottle. You must call `connect()` on a BottleClient instance before making queries')
         results = []
-        for node, mood_dict in mood_data.items():  ## only primitive nodes at this time.
+        if nodes is None:
+            nodes = [node["name"] for node in self.all_nodes]
+        for node in nodes:
             response = requests.post(f'{self.url}{self.genome.primitive_map[node]}/mood/set', verify=self.secure,
-                                     headers=self.headers, json={'data': mood_dict}).json()
-            if 'error' in response or response["message"] != 'updated-genes':
+                                     headers=self.headers, json={'data': mood_data}).json()
+            if 'error' in response or response["message"] != 'set-mood':
                 self.system_failures.append({node: response})
-            if len(mood_data) == 1 and self.summarize_for_single_node:
-                return response['message']
+                print("System Failure:", {node: response})
+                if len(mood_data) == 1 and self.summarize_for_single_node:
+                    return response['message']
             results.append({node: response["message"]})
         return results
 
@@ -528,7 +539,7 @@ class BottleClient:
             nodes = self.all_nodes
         return self._query(requests.post, 'kb/analyze', nodes=nodes)
     
-    def kb_analysis_progress(self): #, nodes: List = None) -> List[Dict[str, Any]]:
+    def kb_analysis_progress(self):
         """
         Monitors the KB analysis progress kickstarted by analyze_kb.
         """
@@ -540,7 +551,7 @@ class BottleClient:
         response = requests.get(f'{self.url}kb/analysis-progress', verify=self.secure, json=[], headers=self.headers).json()
         return response
 
-    def set_target_class(self, target_class: str = None, nodes: List = None) -> List:
+    def set_target_class(self, target_class: str, nodes: List = None) -> List:
         """Provide a target_class symbol for the searcher to look for. It will ignore all other classes.
         This is a symbol that is in the last event of a classification sequence."""
         if nodes is None:
